@@ -1,8 +1,12 @@
-package BSON::Code;
-
+use 5.008001;
 use strict;
 use warnings;
 
+package BSON::Code;
+# ABSTRACT: JavaScript code data for BSON
+
+our $VERSION = '0.12';
+
 sub new {
     my ( $class, $code, $scope ) = @_;
     bless { code => $code, scope => $scope }, $class;
@@ -24,10 +28,18 @@ sub length {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 BSON::Code - JavaScript code data for BSON
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
     use BSON;
@@ -72,20 +84,26 @@ Returns the length of the JavaScript code.
 
 L<BSON>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-minimalist, C<< <minimalist at lavabit.com> >>
+=over 4
 
-=head1 BUGS
+=item *
 
-Bug reports and patches are welcome. Reports which include a failing 
-Test::More style test are helpful and will receive priority.
+minimalist <minimalist@lavabit.com>
 
-=head1 LICENSE AND COPYRIGHT
+=item *
 
-Copyright 2011 minimalist.
+David Golden <david@mongodb.com>
 
-This program is free software; you can redistribute it and/or modify 
-it under the terms as perl itself.
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by minimalist and MongoDB, Inc..
+
+This is free software, licensed under:
+
+  The Apache License, Version 2.0, January 2004
 
 =cut
