@@ -1,7 +1,12 @@
-package BSON::ObjectId;
-
+use 5.008001;
 use strict;
 use warnings;
+
+package BSON::ObjectId;
+# ABSTRACT: ObjectId data element for BSON
+
+our $VERSION = '0.12';
+
 use Carp;
 use Sys::Hostname;
 use Digest::MD5 'md5';
@@ -72,10 +77,18 @@ sub _from_s {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 BSON::ObjectId - ObjectId data element for BSON
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
     use BSON;
@@ -88,6 +101,8 @@ BSON::ObjectId - ObjectId data element for BSON
 
 This module is needed for L<BSON> and it manages BSON's ObjectId element.
 
+=for Pod::Coverage op_eq to_s
+
 =head1 METHODS
 
 =head2 new
@@ -130,20 +145,26 @@ This module is thread safe.
 
 L<BSON>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-minimalist, C<< <minimalist at lavabit.com> >>
+=over 4
 
-=head1 BUGS
+=item *
 
-Bug reports and patches are welcome. Reports which include a failing 
-Test::More style test are helpful and will receive priority.
+minimalist <minimalist@lavabit.com>
 
-=head1 LICENSE AND COPYRIGHT
+=item *
 
-Copyright 2011 minimalist.
+David Golden <david@mongodb.com>
 
-This program is free software; you can redistribute it and/or modify 
-it under the terms as perl itself.
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by minimalist and MongoDB, Inc..
+
+This is free software, licensed under:
+
+  The Apache License, Version 2.0, January 2004
 
 =cut
