@@ -1,8 +1,12 @@
-package BSON::String;
-
+use 5.008001;
 use strict;
 use warnings;
 
+package BSON::String;
+# ABSTRACT: String data for BSON
+
+our $VERSION = '0.12';
+
 use overload '""' => \&value;
 
 sub new {
@@ -18,10 +22,18 @@ sub value {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 BSON::String - String data for BSON
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
     use BSON 'encode';
@@ -32,7 +44,6 @@ BSON::String - String data for BSON
 
     my $bson = encode( { a => $str1, b => $str2, c => $str3 } );
 
-
 =head1 DESCRIPTION
 
 Since Perl does not distinguish between numbers and strings, this module 
@@ -67,20 +78,26 @@ comparison on a BSON::String instance.
 
 L<BSON>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-minimalist, C<< <minimalist at lavabit.com> >>
+=over 4
 
-=head1 BUGS
+=item *
 
-Bug reports and patches are welcome. Reports which include a failing 
-Test::More style test are helpful and will receive priority.
+minimalist <minimalist@lavabit.com>
 
-=head1 LICENSE AND COPYRIGHT
+=item *
 
-Copyright 2011 minimalist.
+David Golden <david@mongodb.com>
 
-This program is free software; you can redistribute it and/or modify 
-it under the terms as perl itself.
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by minimalist and MongoDB, Inc..
+
+This is free software, licensed under:
+
+  The Apache License, Version 2.0, January 2004
 
 =cut
